[−][src]Trait mini_haskell::utils::control::Either
The std::ops::Try trait is not yet stable. We roll up our own for now.
It is named after Either, Left, and Right from Haskell.
The std::ops::Try trait is not yet stable. We roll up our own for now.
It is named after Either, Left, and Right from Haskell.
fn left(x: Self::Left) -> Selffn right(x: Self::Right) -> Selffn into_result(self) -> Result<Self::Right, Self::Left>impl<T> Either for Option<T>[src]type Left = Option<Void>type Right = Tfn left(_: Option<Void>) -> Self[src]fn right(x: T) -> Self[src]fn into_result(self) -> Result<T, Option<Void>>[src]impl<T, E> Either for Result<T, E>[src]type Left = Etype Right = Tfn left(x: E) -> Self[src]fn right(x: T) -> Self[src]fn into_result(self) -> Result<T, E>[src]